@@ -14,7 +14,9 @@
  * SOFTWARE.
  */
 
+mod compatibility;
 mod examples;
 
+pub use compatibility::*;
+pub use examples::valid::*;
 pub use examples::*;
-pub use examples::valid::*;
\ No newline at end of file
